@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018 Red Hat, Inc.
+ * Copyright (c) 2012-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -21,6 +21,8 @@ import com.google.inject.assistedinject.FactoryModuleBuilder;
 import com.google.inject.multibindings.MapBinder;
 import com.google.inject.multibindings.Multibinder;
 import com.google.inject.name.Names;
+import io.jsonwebtoken.JwtParser;
+import io.jsonwebtoken.impl.DefaultJwtParser;
 import java.util.HashMap;
 import java.util.Map;
 import javax.sql.DataSource;
@@ -33,17 +35,24 @@ import org.eclipse.che.api.factory.server.FactoryAcceptValidator;
 import org.eclipse.che.api.factory.server.FactoryCreateValidator;
 import org.eclipse.che.api.factory.server.FactoryEditValidator;
 import org.eclipse.che.api.factory.server.FactoryParametersResolver;
+import org.eclipse.che.api.factory.server.ScmFileResolver;
+import org.eclipse.che.api.factory.server.ScmService;
 import org.eclipse.che.api.factory.server.bitbucket.BitbucketServerAuthorizingFactoryParametersResolver;
+import org.eclipse.che.api.factory.server.bitbucket.BitbucketServerScmFileResolver;
 import org.eclipse.che.api.factory.server.github.GithubFactoryParametersResolver;
+import org.eclipse.che.api.factory.server.github.GithubScmFileResolver;
 import org.eclipse.che.api.factory.server.gitlab.GitlabFactoryParametersResolver;
+import org.eclipse.che.api.factory.server.gitlab.GitlabScmFileResolver;
 import org.eclipse.che.api.infraproxy.server.InfraProxyModule;
 import org.eclipse.che.api.metrics.WsMasterMetricsModule;
 import org.eclipse.che.api.system.server.ServiceTermination;
 import org.eclipse.che.api.system.server.SystemModule;
 import org.eclipse.che.api.user.server.TokenValidator;
 import org.eclipse.che.api.user.server.jpa.JpaPreferenceDao;
+import org.eclipse.che.api.user.server.jpa.JpaProfileDao;
 import org.eclipse.che.api.user.server.jpa.JpaUserDao;
 import org.eclipse.che.api.user.server.spi.PreferenceDao;
+import org.eclipse.che.api.user.server.spi.ProfileDao;
 import org.eclipse.che.api.user.server.spi.UserDao;
 import org.eclipse.che.api.workspace.server.WorkspaceEntityProvider;
 import org.eclipse.che.api.workspace.server.WorkspaceLockService;
@@ -72,8 +81,10 @@ import org.eclipse.che.commons.observability.deploy.ExecutorWrapperModule;
 import org.eclipse.che.core.db.DBTermination;
 import org.eclipse.che.core.db.schema.SchemaInitializer;
 import org.eclipse.che.core.tracing.metrics.TracingMetricsModule;
+import org.eclipse.che.inject.ConfigurationException;
 import org.eclipse.che.inject.DynaModule;
 import org.eclipse.che.multiuser.api.authentication.commons.token.ChainedTokenExtractor;
+import org.eclipse.che.multiuser.api.authentication.commons.token.HeaderRequestTokenExtractor;
 import org.eclipse.che.multiuser.api.authentication.commons.token.RequestTokenExtractor;
 import org.eclipse.che.multiuser.api.permission.server.AdminPermissionInitializer;
 import org.eclipse.che.multiuser.api.permission.server.PermissionChecker;
@@ -91,9 +102,11 @@ import org.eclipse.che.security.PasswordEncryptor;
 import org.eclipse.che.security.oauth.EmbeddedOAuthAPI;
 import org.eclipse.che.security.oauth.OAuthAPI;
 import org.eclipse.che.security.oauth.OpenShiftOAuthModule;
+import org.eclipse.che.workspace.infrastructure.kubernetes.KubernetesClientConfigFactory;
 import org.eclipse.che.workspace.infrastructure.kubernetes.KubernetesInfraModule;
 import org.eclipse.che.workspace.infrastructure.kubernetes.KubernetesInfrastructure;
 import org.eclipse.che.workspace.infrastructure.kubernetes.environment.KubernetesEnvironment;
+import org.eclipse.che.workspace.infrastructure.kubernetes.multiuser.oauth.KubernetesOidcProviderConfigFactory;
 import org.eclipse.che.workspace.infrastructure.kubernetes.server.secure.SecureServerExposer;
 import org.eclipse.che.workspace.infrastructure.kubernetes.server.secure.SecureServerExposerFactory;
 import org.eclipse.che.workspace.infrastructure.kubernetes.server.secure.jwtproxy.PassThroughProxySecureServerExposer;
@@ -103,11 +116,10 @@ import org.eclipse.che.workspace.infrastructure.kubernetes.server.secure.jwtprox
 import org.eclipse.che.workspace.infrastructure.kubernetes.server.secure.jwtproxy.factory.PassThroughProxyProvisionerFactory;
 import org.eclipse.che.workspace.infrastructure.kubernetes.server.secure.jwtproxy.factory.PassThroughProxySecureServerExposerFactory;
 import org.eclipse.che.workspace.infrastructure.metrics.InfrastructureMetricsModule;
-import org.eclipse.che.workspace.infrastructure.openshift.OpenShiftClientConfigFactory;
 import org.eclipse.che.workspace.infrastructure.openshift.OpenShiftInfraModule;
 import org.eclipse.che.workspace.infrastructure.openshift.OpenShiftInfrastructure;
 import org.eclipse.che.workspace.infrastructure.openshift.environment.OpenShiftEnvironment;
-import org.eclipse.che.workspace.infrastructure.openshift.multiuser.oauth.IdentityProviderConfigFactory;
+import org.eclipse.che.workspace.infrastructure.openshift.multiuser.oauth.KeycloakProviderConfigFactory;
 import org.eclipse.persistence.config.PersistenceUnitProperties;
 import org.flywaydb.core.internal.util.PlaceholderReplacer;
 
@@ -145,6 +157,7 @@ public class WsMasterModule extends AbstractModule {
     bind(FactoryEditValidator.class)
         .to(org.eclipse.che.api.factory.server.impl.FactoryEditValidatorImpl.class);
     bind(org.eclipse.che.api.factory.server.FactoryService.class);
+    bind(ScmService.class);
     install(new org.eclipse.che.api.factory.server.jpa.FactoryJpaModule());
 
     // Service-specific factory resolvers.
@@ -156,6 +169,12 @@ public class WsMasterModule extends AbstractModule {
         .to(BitbucketServerAuthorizingFactoryParametersResolver.class);
     factoryParametersResolverMultibinder.addBinding().to(GitlabFactoryParametersResolver.class);
 
+    Multibinder<ScmFileResolver> scmFileResolverResolverMultibinder =
+        Multibinder.newSetBinder(binder(), ScmFileResolver.class);
+    scmFileResolverResolverMultibinder.addBinding().to(GithubScmFileResolver.class);
+    scmFileResolverResolverMultibinder.addBinding().to(GitlabScmFileResolver.class);
+    scmFileResolverResolverMultibinder.addBinding().to(BitbucketServerScmFileResolver.class);
+
     install(new org.eclipse.che.api.factory.server.scm.KubernetesScmModule());
     install(new org.eclipse.che.api.factory.server.bitbucket.BitbucketServerModule());
     install(new org.eclipse.che.api.factory.server.gitlab.GitlabModule());
@@ -357,7 +376,17 @@ public class WsMasterModule extends AbstractModule {
     }
 
     if (OpenShiftInfrastructure.NAME.equals(infrastructure)) {
-      bind(OpenShiftClientConfigFactory.class).to(IdentityProviderConfigFactory.class);
+      if (Boolean.parseBoolean(System.getenv("CHE_AUTH_NATIVEUSER"))) {
+        bind(KubernetesClientConfigFactory.class).to(KubernetesOidcProviderConfigFactory.class);
+      } else {
+        bind(KubernetesClientConfigFactory.class).to(KeycloakProviderConfigFactory.class);
+      }
+    }
+
+    if (KubernetesInfrastructure.NAME.equals(infrastructure)
+        && Boolean.parseBoolean(System.getenv("CHE_AUTH_NATIVEUSER"))) {
+      throw new ConfigurationException(
+          "Native user mode is not supported on Kubernetes. It is supported only on OpenShift.");
     }
 
     persistenceProperties.put(
@@ -393,7 +422,7 @@ public class WsMasterModule extends AbstractModule {
     bind(org.eclipse.che.multiuser.permission.logger.LoggerServicePermissionsFilter.class);
 
     bind(org.eclipse.che.multiuser.permission.workspace.activity.ActivityPermissionsFilter.class);
-    bind(AdminPermissionInitializer.class).asEagerSingleton();
+
     bind(
         org.eclipse.che.multiuser.permission.resource.filters.ResourceServicePermissionsFilter
             .class);
@@ -405,11 +434,20 @@ public class WsMasterModule extends AbstractModule {
     install(new OrganizationApiModule());
     install(new OrganizationJpaModule());
 
-    install(new KeycloakModule());
-    install(new KeycloakUserRemoverModule());
+    if (Boolean.parseBoolean(System.getenv("CHE_AUTH_NATIVEUSER"))) {
+      bind(TokenValidator.class).to(org.eclipse.che.api.local.DummyTokenValidator.class);
+      bind(JwtParser.class).to(DefaultJwtParser.class);
+      bind(ProfileDao.class).to(JpaProfileDao.class);
+      bind(OAuthAPI.class).to(EmbeddedOAuthAPI.class);
+      bind(RequestTokenExtractor.class).to(HeaderRequestTokenExtractor.class);
+    } else {
+      install(new KeycloakModule());
+      install(new KeycloakUserRemoverModule());
+      bind(AdminPermissionInitializer.class).asEagerSingleton();
+      bind(RequestTokenExtractor.class).to(ChainedTokenExtractor.class);
+    }
 
     install(new MachineAuthModule());
-    bind(RequestTokenExtractor.class).to(ChainedTokenExtractor.class);
 
     // User and profile - use profile from keycloak and other stuff is JPA
     bind(PasswordEncryptor.class).to(PBKDF2PasswordEncryptor.class);
@@ -419,9 +457,7 @@ public class WsMasterModule extends AbstractModule {
 
     bindConstant().annotatedWith(Names.named("che.agents.auth_enabled")).to(true);
 
-    if (OpenShiftInfrastructure.NAME.equals(infrastructure)) {
-      install(new InfraProxyModule());
-    }
+    install(new InfraProxyModule());
   }
 
   private void configureJwtProxySecureProvisioner(String infrastructure) {
