@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018 Red Hat, Inc.
+ * Copyright (c) 2012-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -20,12 +20,14 @@ import static org.mockito.Mockito.lenient;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.verifyNoMoreInteractions;
+import static org.mockito.Mockito.verifyZeroInteractions;
 import static org.mockito.Mockito.when;
 import static org.testng.Assert.assertEquals;
 import static org.testng.Assert.assertNotNull;
 import static org.testng.Assert.assertTrue;
 
-import io.fabric8.kubernetes.api.model.DoneableServiceAccount;
+import com.google.common.collect.ImmutableList;
 import io.fabric8.kubernetes.api.model.Namespace;
 import io.fabric8.kubernetes.api.model.NamespaceBuilder;
 import io.fabric8.kubernetes.api.model.ServiceAccount;
@@ -35,11 +37,15 @@ import io.fabric8.kubernetes.client.KubernetesClientException;
 import io.fabric8.kubernetes.client.dsl.MixedOperation;
 import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
 import io.fabric8.kubernetes.client.dsl.Resource;
-import io.fabric8.openshift.api.model.DoneableProjectRequest;
 import io.fabric8.openshift.api.model.Project;
 import io.fabric8.openshift.api.model.ProjectBuilder;
+import io.fabric8.openshift.api.model.ProjectRequest;
 import io.fabric8.openshift.api.model.ProjectRequestFluent.MetadataNested;
+import io.fabric8.openshift.api.model.RoleBinding;
+import io.fabric8.openshift.api.model.RoleBindingList;
+import io.fabric8.openshift.api.model.UserBuilder;
 import io.fabric8.openshift.client.OpenShiftClient;
+import io.fabric8.openshift.client.dsl.ProjectOperation;
 import io.fabric8.openshift.client.dsl.ProjectRequestOperation;
 import java.util.Map;
 import java.util.concurrent.Executor;
@@ -51,10 +57,12 @@ import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.KubernetesI
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.KubernetesPersistentVolumeClaims;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.KubernetesSecrets;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.KubernetesServices;
+import org.eclipse.che.workspace.infrastructure.openshift.CheServerOpenshiftClientFactory;
 import org.eclipse.che.workspace.infrastructure.openshift.OpenShiftClientFactory;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
 import org.mockito.testng.MockitoTestNGListener;
+import org.testng.Assert;
 import org.testng.annotations.BeforeMethod;
 import org.testng.annotations.Listeners;
 import org.testng.annotations.Test;
@@ -79,10 +87,22 @@ public class OpenShiftProjectTest {
   @Mock private KubernetesConfigsMaps configsMaps;
   @Mock private OpenShiftClientFactory clientFactory;
   @Mock private CheServerKubernetesClientFactory cheClientFactory;
+  @Mock private CheServerOpenshiftClientFactory cheServerOpenshiftClientFactory;
   @Mock private Executor executor;
   @Mock private OpenShiftClient openShiftClient;
+  @Mock private OpenShiftClient openShiftCheServerClient;
   @Mock private KubernetesClient kubernetesClient;
-  @Mock private Resource<ServiceAccount, DoneableServiceAccount> serviceAccountResource;
+  @Mock private Resource<ServiceAccount> serviceAccountResource;
+  @Mock private ProjectRequestOperation projectRequestOperation;
+  @Mock private MetadataNested metadataNested;
+
+  @Mock
+  private MixedOperation<RoleBinding, RoleBindingList, Resource<RoleBinding>>
+      mixedRoleBindingOperation;
+
+  @Mock
+  private NonNamespaceOperation<RoleBinding, RoleBindingList, Resource<RoleBinding>>
+      nonNamespaceRoleBindingOperation;
 
   private OpenShiftProject openShiftProject;
 
@@ -91,6 +111,9 @@ public class OpenShiftProjectTest {
     lenient().when(clientFactory.create(anyString())).thenReturn(kubernetesClient);
     lenient().when(clientFactory.createOC()).thenReturn(openShiftClient);
     lenient().when(clientFactory.createOC(anyString())).thenReturn(openShiftClient);
+
+    lenient().when(cheServerOpenshiftClientFactory.createOC()).thenReturn(openShiftCheServerClient);
+
     lenient().when(openShiftClient.adapt(OpenShiftClient.class)).thenReturn(openShiftClient);
 
     final MixedOperation mixedOperation = mock(MixedOperation.class);
@@ -99,11 +122,14 @@ public class OpenShiftProjectTest {
     lenient().when(mixedOperation.inNamespace(anyString())).thenReturn(namespaceOperation);
     lenient().when(namespaceOperation.withName(anyString())).thenReturn(serviceAccountResource);
     lenient().when(serviceAccountResource.get()).thenReturn(mock(ServiceAccount.class));
+    lenient().doReturn(projectRequestOperation).when(openShiftClient).projectrequests();
+    lenient().doReturn(metadataNested).when(metadataNested).withName(anyString());
 
     openShiftProject =
         new OpenShiftProject(
             clientFactory,
             cheClientFactory,
+            cheServerOpenshiftClientFactory,
             WORKSPACE_ID,
             PROJECT_NAME,
             deployments,
@@ -118,36 +144,121 @@ public class OpenShiftProjectTest {
   @Test
   public void testOpenShiftProjectPreparingWhenProjectExists() throws Exception {
     // given
-    MetadataNested projectMeta = prepareProjectRequest();
     prepareNamespaceGet(PROJECT_NAME);
 
     prepareProject(PROJECT_NAME);
     OpenShiftProject project =
-        new OpenShiftProject(clientFactory, cheClientFactory, executor, PROJECT_NAME, WORKSPACE_ID);
+        new OpenShiftProject(
+            clientFactory,
+            cheClientFactory,
+            cheServerOpenshiftClientFactory,
+            executor,
+            PROJECT_NAME,
+            WORKSPACE_ID);
 
     // when
-    project.prepare(true, Map.of());
+    project.prepare(true, true, Map.of());
 
     // then
-    verify(projectMeta, never()).withName(PROJECT_NAME);
+    verify(metadataNested, never()).withName(PROJECT_NAME);
   }
 
   @Test
   public void testOpenShiftProjectPreparingWhenProjectDoesNotExist() throws Exception {
     // given
-    MetadataNested projectMetadata = prepareProjectRequest();
     prepareNamespaceGet(PROJECT_NAME);
 
     Resource resource = prepareProjectResource(PROJECT_NAME);
     doThrow(new KubernetesClientException("error", 403, null)).when(resource).get();
     OpenShiftProject project =
-        new OpenShiftProject(clientFactory, cheClientFactory, executor, PROJECT_NAME, WORKSPACE_ID);
+        new OpenShiftProject(
+            clientFactory,
+            cheClientFactory,
+            cheServerOpenshiftClientFactory,
+            executor,
+            PROJECT_NAME,
+            WORKSPACE_ID);
 
     // when
-    openShiftProject.prepare(true, Map.of());
+    openShiftProject.prepare(true, false, Map.of());
 
     // then
-    verify(projectMetadata).withName(PROJECT_NAME);
+    ArgumentCaptor<ProjectRequest> captor = ArgumentCaptor.forClass(ProjectRequest.class);
+    verify(projectRequestOperation).create(captor.capture());
+    Assert.assertEquals(captor.getValue().getMetadata().getName(), PROJECT_NAME);
+  }
+
+  @Test
+  public void testOpenShiftProjectPreparingWhenProjectDoesNotExistWithCheServerSA()
+      throws Exception {
+    // given
+    prepareNamespaceGet(PROJECT_NAME);
+
+    Resource resource = prepareProjectResource(PROJECT_NAME);
+    doThrow(new KubernetesClientException("error", 403, null)).when(resource).get();
+    final MixedOperation mixedOperation = mock(MixedOperation.class);
+    final NonNamespaceOperation namespaceOperation = mock(NonNamespaceOperation.class);
+    doReturn(mixedOperation).when(openShiftCheServerClient).serviceAccounts();
+    when(mixedOperation.inNamespace(anyString())).thenReturn(namespaceOperation);
+    when(namespaceOperation.withName(anyString())).thenReturn(serviceAccountResource);
+    when(serviceAccountResource.get()).thenReturn(mock(ServiceAccount.class));
+    doReturn(projectRequestOperation).when(openShiftCheServerClient).projectrequests();
+    // doReturn(metadataNested).when(metadataNested).withName(anyString());
+    when(openShiftCheServerClient.roleBindings()).thenReturn(mixedRoleBindingOperation);
+    lenient()
+        .when(mixedRoleBindingOperation.inNamespace(anyString()))
+        .thenReturn(nonNamespaceRoleBindingOperation);
+    when(openShiftClient.currentUser())
+        .thenReturn(new UserBuilder().withNewMetadata().withName("user").endMetadata().build());
+    // when
+    openShiftProject.prepare(true, true, Map.of());
+
+    // then
+    ArgumentCaptor<ProjectRequest> captor = ArgumentCaptor.forClass(ProjectRequest.class);
+    verify(projectRequestOperation).create(captor.capture());
+    Assert.assertEquals(captor.getValue().getMetadata().getName(), PROJECT_NAME);
+    verifyNoMoreInteractions(openShiftCheServerClient);
+    verifyZeroInteractions(kubernetesClient);
+    ArgumentCaptor<RoleBinding> roleBindingArgumentCaptor =
+        ArgumentCaptor.forClass(RoleBinding.class);
+    verify(nonNamespaceRoleBindingOperation).createOrReplace(roleBindingArgumentCaptor.capture());
+    assertNotNull(roleBindingArgumentCaptor.getValue());
+  }
+
+  @Test(dependsOnMethods = "testOpenShiftProjectPreparingWhenProjectDoesNotExistWithCheServerSA")
+  public void testOpenShiftProjectPreparingRoleBindingWhenProjectDoesNotExistWithCheServerSA()
+      throws Exception {
+    // given
+    prepareNamespaceGet(PROJECT_NAME);
+
+    Resource resource = prepareProjectResource(PROJECT_NAME);
+    doThrow(new KubernetesClientException("error", 403, null)).when(resource).get();
+    final MixedOperation mixedOperation = mock(MixedOperation.class);
+    final NonNamespaceOperation namespaceOperation = mock(NonNamespaceOperation.class);
+    doReturn(mixedOperation).when(openShiftCheServerClient).serviceAccounts();
+    when(mixedOperation.inNamespace(anyString())).thenReturn(namespaceOperation);
+    when(namespaceOperation.withName(anyString())).thenReturn(serviceAccountResource);
+    when(serviceAccountResource.get()).thenReturn(mock(ServiceAccount.class));
+    doReturn(projectRequestOperation).when(openShiftCheServerClient).projectrequests();
+    // doReturn(metadataNested).when(metadataNested).withName(anyString());
+    when(openShiftCheServerClient.roleBindings()).thenReturn(mixedRoleBindingOperation);
+    lenient()
+        .when(mixedRoleBindingOperation.inNamespace(anyString()))
+        .thenReturn(nonNamespaceRoleBindingOperation);
+    when(openShiftClient.currentUser())
+        .thenReturn(new UserBuilder().withNewMetadata().withName("jdoe").endMetadata().build());
+    // when
+    openShiftProject.prepare(true, true, Map.of());
+
+    // then
+    ArgumentCaptor<RoleBinding> roleBindingArgumentCaptor =
+        ArgumentCaptor.forClass(RoleBinding.class);
+    verify(nonNamespaceRoleBindingOperation).createOrReplace(roleBindingArgumentCaptor.capture());
+    RoleBinding roleBinding = roleBindingArgumentCaptor.getValue();
+    assertNotNull(roleBinding);
+    assertEquals(roleBinding.getMetadata().getName(), "admin");
+    assertEquals(roleBinding.getRoleRef().getName(), "admin");
+    assertEquals(roleBinding.getUserNames(), ImmutableList.of("jdoe"));
   }
 
   @Test(expectedExceptions = InfrastructureException.class)
@@ -156,10 +267,16 @@ public class OpenShiftProjectTest {
     Resource resource = prepareProjectResource(PROJECT_NAME);
     doThrow(new KubernetesClientException("error", 403, null)).when(resource).get();
     OpenShiftProject project =
-        new OpenShiftProject(clientFactory, cheClientFactory, executor, PROJECT_NAME, WORKSPACE_ID);
+        new OpenShiftProject(
+            clientFactory,
+            cheClientFactory,
+            cheServerOpenshiftClientFactory,
+            executor,
+            PROJECT_NAME,
+            WORKSPACE_ID);
 
     // when
-    project.prepare(false, Map.of());
+    project.prepare(false, true, Map.of());
 
     // then
     // exception is thrown
@@ -202,7 +319,13 @@ public class OpenShiftProjectTest {
   public void testDeletesExistingProject() throws Exception {
     // given
     OpenShiftProject project =
-        new OpenShiftProject(clientFactory, cheClientFactory, executor, PROJECT_NAME, WORKSPACE_ID);
+        new OpenShiftProject(
+            clientFactory,
+            cheClientFactory,
+            cheServerOpenshiftClientFactory,
+            executor,
+            PROJECT_NAME,
+            WORKSPACE_ID);
     Resource resource = prepareProjectResource(PROJECT_NAME);
 
     // when
@@ -216,7 +339,13 @@ public class OpenShiftProjectTest {
   public void testDoesntFailIfDeletedProjectDoesntExist() throws Exception {
     // given
     OpenShiftProject project =
-        new OpenShiftProject(clientFactory, cheClientFactory, executor, PROJECT_NAME, WORKSPACE_ID);
+        new OpenShiftProject(
+            clientFactory,
+            cheClientFactory,
+            cheServerOpenshiftClientFactory,
+            executor,
+            PROJECT_NAME,
+            WORKSPACE_ID);
     Resource resource = prepareProjectResource(PROJECT_NAME);
     when(resource.get()).thenThrow(new KubernetesClientException("err", 404, null));
     when(resource.delete()).thenThrow(new KubernetesClientException("err", 404, null));
@@ -233,7 +362,13 @@ public class OpenShiftProjectTest {
   public void testDoesntFailIfDeletedProjectIsBeingDeleted() throws Exception {
     // given
     OpenShiftProject project =
-        new OpenShiftProject(clientFactory, cheClientFactory, executor, PROJECT_NAME, WORKSPACE_ID);
+        new OpenShiftProject(
+            clientFactory,
+            cheClientFactory,
+            cheServerOpenshiftClientFactory,
+            executor,
+            PROJECT_NAME,
+            WORKSPACE_ID);
     Resource resource = prepareProjectResource(PROJECT_NAME);
     when(resource.delete()).thenThrow(new KubernetesClientException("err", 409, null));
 
@@ -251,7 +386,13 @@ public class OpenShiftProjectTest {
     prepareProject(PROJECT_NAME);
     prepareNamespaceGet(PROJECT_NAME);
     OpenShiftProject openShiftProject =
-        new OpenShiftProject(clientFactory, cheClientFactory, executor, PROJECT_NAME, WORKSPACE_ID);
+        new OpenShiftProject(
+            clientFactory,
+            cheClientFactory,
+            cheServerOpenshiftClientFactory,
+            executor,
+            PROJECT_NAME,
+            WORKSPACE_ID);
 
     KubernetesClient cheKubeClient = mock(KubernetesClient.class);
     doReturn(cheKubeClient).when(cheClientFactory).create();
@@ -267,7 +408,7 @@ public class OpenShiftProjectTest {
     Map<String, String> labels = Map.of("label.with.this", "yes", "and.this", "of courese");
 
     // when
-    openShiftProject.prepare(true, labels);
+    openShiftProject.prepare(true, true, labels);
 
     // then
     Namespace updatedNamespace = namespaceArgumentCaptor.getValue();
@@ -285,7 +426,13 @@ public class OpenShiftProjectTest {
     Namespace namespace = prepareNamespaceGet(PROJECT_NAME);
     namespace.getMetadata().setLabels(labels);
     OpenShiftProject openShiftProject =
-        new OpenShiftProject(clientFactory, cheClientFactory, executor, PROJECT_NAME, WORKSPACE_ID);
+        new OpenShiftProject(
+            clientFactory,
+            cheClientFactory,
+            cheServerOpenshiftClientFactory,
+            executor,
+            PROJECT_NAME,
+            WORKSPACE_ID);
 
     KubernetesClient cheKubeClient = mock(KubernetesClient.class);
     doReturn(cheKubeClient).when(cheClientFactory).create();
@@ -298,7 +445,7 @@ public class OpenShiftProjectTest {
         .createOrReplace(any(Namespace.class));
 
     // when
-    openShiftProject.prepare(true, labels);
+    openShiftProject.prepare(true, true, labels);
 
     // then
     assertTrue(namespace.getMetadata().getLabels().entrySet().containsAll(labels.entrySet()));
@@ -313,7 +460,13 @@ public class OpenShiftProjectTest {
     prepareProject(PROJECT_NAME);
     prepareNamespaceGet(PROJECT_NAME);
     OpenShiftProject openShiftProject =
-        new OpenShiftProject(clientFactory, cheClientFactory, executor, PROJECT_NAME, WORKSPACE_ID);
+        new OpenShiftProject(
+            clientFactory,
+            cheClientFactory,
+            cheServerOpenshiftClientFactory,
+            executor,
+            PROJECT_NAME,
+            WORKSPACE_ID);
 
     KubernetesClient cheKubeClient = mock(KubernetesClient.class);
     lenient().doReturn(cheKubeClient).when(cheClientFactory).create();
@@ -328,7 +481,7 @@ public class OpenShiftProjectTest {
         .createOrReplace(namespaceArgumentCaptor.capture());
 
     // when
-    openShiftProject.prepare(true, labels);
+    openShiftProject.prepare(true, true, labels);
 
     // then
     Namespace updatedNamespace = namespaceArgumentCaptor.getValue();
@@ -345,7 +498,13 @@ public class OpenShiftProjectTest {
     prepareProject(PROJECT_NAME);
     Namespace namespace = prepareNamespaceGet(PROJECT_NAME);
     OpenShiftProject openShiftProject =
-        new OpenShiftProject(clientFactory, cheClientFactory, executor, PROJECT_NAME, WORKSPACE_ID);
+        new OpenShiftProject(
+            clientFactory,
+            cheClientFactory,
+            cheServerOpenshiftClientFactory,
+            executor,
+            PROJECT_NAME,
+            WORKSPACE_ID);
 
     KubernetesClient cheKubeClient = mock(KubernetesClient.class);
     lenient().doReturn(cheKubeClient).when(cheClientFactory).create();
@@ -359,29 +518,16 @@ public class OpenShiftProjectTest {
         .createOrReplace(any(Namespace.class));
 
     // when
-    openShiftProject.prepare(true, labels);
+    openShiftProject.prepare(true, true, labels);
 
     // then
     verify(nonNamespaceOperation).createOrReplace(namespace);
   }
 
-  private MetadataNested prepareProjectRequest() {
-    ProjectRequestOperation projectRequestOperation = mock(ProjectRequestOperation.class);
-    DoneableProjectRequest projectRequest = mock(DoneableProjectRequest.class);
-    MetadataNested metadataNested = mock(MetadataNested.class);
-
-    lenient().doReturn(projectRequestOperation).when(openShiftClient).projectrequests();
-    lenient().doReturn(projectRequest).when(projectRequestOperation).createNew();
-    lenient().doReturn(metadataNested).when(projectRequest).withNewMetadata();
-    lenient().doReturn(metadataNested).when(metadataNested).withName(anyString());
-    lenient().doReturn(projectRequest).when(metadataNested).endMetadata();
-    return metadataNested;
-  }
-
   private Resource prepareProjectResource(String projectName) {
     Resource projectResource = mock(Resource.class);
 
-    NonNamespaceOperation projectOperation = mock(NonNamespaceOperation.class);
+    ProjectOperation projectOperation = mock(ProjectOperation.class);
     doReturn(projectResource).when(projectOperation).withName(projectName);
     doReturn(projectOperation).when(openShiftClient).projects();
 
