@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018 Red Hat, Inc.
+ * Copyright (c) 2012-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -598,7 +598,7 @@ public class WorkspaceManagerTest {
     DevfileImpl devfile = mock(DevfileImpl.class);
     WorkspaceImpl workspace = createAndMockWorkspace(devfile, NAMESPACE_1, new HashMap<>());
     workspace.getAttributes().remove(WORKSPACE_INFRASTRUCTURE_NAMESPACE_ATTRIBUTE);
-    when(runtimes.evalLegacyInfrastructureNamespace(any())).thenReturn("evaluated-legacy");
+    when(runtimes.evalInfrastructureNamespace(any())).thenReturn("evaluated-legacy");
 
     EnvironmentImpl environment = new EnvironmentImpl(null, emptyMap());
     Command command = new CommandImpl("cmd", "echo hello", "custom");
@@ -627,7 +627,7 @@ public class WorkspaceManagerTest {
             .get(WORKSPACE_INFRASTRUCTURE_NAMESPACE_ATTRIBUTE),
         "evaluated-legacy");
     verify(runtimes)
-        .evalLegacyInfrastructureNamespace(
+        .evalInfrastructureNamespace(
             new NamespaceResolutionContext(workspace.getId(), USER_ID, NAMESPACE_1));
   }
 
@@ -708,7 +708,7 @@ public class WorkspaceManagerTest {
             .getAttributes()
             .get(WORKSPACE_INFRASTRUCTURE_NAMESPACE_ATTRIBUTE),
         "user-defined");
-    verify(runtimes, never()).evalLegacyInfrastructureNamespace(any());
+    verify(runtimes, never()).evalInfrastructureNamespace(any());
   }
 
   @Test
