@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018 Red Hat, Inc.
+ * Copyright (c) 2012-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -1059,12 +1059,6 @@ public class WorkspaceRuntimesTest {
       return "defaultNamespace";
     }
 
-    @Override
-    public String evaluateLegacyInfraNamespace(NamespaceResolutionContext resolutionContext)
-        throws InfrastructureException {
-      return "defaultLegacyNamespace";
-    }
-
     @Override
     public boolean isNamespaceValid(String namespaceName) {
       return true;
