@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018 Red Hat, Inc.
+ * Copyright (c) 2012-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -228,47 +228,6 @@ public class WorkspaceServiceTest {
             any());
   }
 
-  @Test
-  public void shouldCreateWorkspaceFromDevfileInNamespace() throws Exception {
-    final DevfileDto devfileDto = createDevfileDto();
-    final WorkspaceImpl workspace = createWorkspace(devfileDto);
-
-    when(wsManager.createWorkspace(any(Devfile.class), anyString(), any(), any()))
-        .thenReturn(workspace);
-
-    final Response response =
-        given()
-            .auth()
-            .basic(ADMIN_USER_NAME, ADMIN_USER_PASSWORD)
-            .contentType("application/json")
-            .body(devfileDto)
-            .when()
-            .post(
-                SECURE_PATH
-                    + "/workspace/devfile"
-                    + "?namespace=test"
-                    + "&attribute=factoryId:factory123"
-                    + "&attribute=custom:custom:value"
-                    + "&infrastructure-namespace=my-namespace");
-
-    assertEquals(response.getStatusCode(), 201);
-    assertEquals(
-        new WorkspaceImpl(unwrapDto(response, WorkspaceDto.class), TEST_ACCOUNT), workspace);
-    verify(wsManager)
-        .createWorkspace(
-            any(Devfile.class),
-            eq("test"),
-            eq(
-                ImmutableMap.of(
-                    "factoryId",
-                    "factory123",
-                    "custom",
-                    "custom:value",
-                    "infrastructureNamespace",
-                    "my-namespace")),
-            any());
-  }
-
   @Test
   public void shouldReturnBadRequestOnInvalidDevfile() throws Exception {
     final DevfileDto devfileDto = createDevfileDto();
